@@ -106,10 +106,10 @@ impl ServerVersion {
 /// is sent.
 #[derive(Debug, Copy, Clone, Eq, PartialEq, Deserialize)]
 pub struct Limits {
-    packet_len: u64,
-    read_len: u64,
-    write_len: u64,
-    open_handles: u64,
+    pub packet_len: u64,
+    pub read_len: u64,
+    pub write_len: u64,
+    pub open_handles: u64,
 }
 
 #[derive(Debug)]
